# coding: utf-8

"""
Mux Python - Copyright 2019 Mux Inc.

NOTE: This class is auto generated. Do not edit the class manually.
"""


import pprint
import re  # noqa: F401
import six

class InputSettings(object):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'url': 'str',
        'overlay_settings': 'InputSettingsOverlaySettings',
        'type': 'str',
        'text_type': 'str',
        'language_code': 'str',
        'name': 'str',
        'closed_captions': 'bool',
        'passthrough': 'str'
    }

    attribute_map = {
        'url': 'url',
        'overlay_settings': 'overlay_settings',
        'type': 'type',
        'text_type': 'text_type',
        'language_code': 'language_code',
        'name': 'name',
        'closed_captions': 'closed_captions',
        'passthrough': 'passthrough'
    }

    def __init__(self, url=None, overlay_settings=None, type=None, text_type=None, language_code=None, name=None, closed_captions=None, passthrough=None):  # noqa: E501
        """InputSettings - a model defined in OpenAPI"""  # noqa: E501

        self._url = None
        self._overlay_settings = None
        self._type = None
        self._text_type = None
        self._language_code = None
        self._name = None
        self._closed_captions = None
        self._passthrough = None
        self.discriminator = None

        if url is not None:
            self.url = url
        if overlay_settings is not None:
            self.overlay_settings = overlay_settings
        if type is not None:
            self.type = type
        if text_type is not None:
            self.text_type = text_type
        if language_code is not None:
            self.language_code = language_code
        if name is not None:
            self.name = name
        if closed_captions is not None:
            self.closed_captions = closed_captions
        if passthrough is not None:
            self.passthrough = passthrough

    @property
    def url(self):
        """Gets the url of this InputSettings.  # noqa: E501


        :return: The url of this InputSettings.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this InputSettings.


        :param url: The url of this InputSettings.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def overlay_settings(self):
        """Gets the overlay_settings of this InputSettings.  # noqa: E501


        :return: The overlay_settings of this InputSettings.  # noqa: E501
        :rtype: InputSettingsOverlaySettings
        """
        return self._overlay_settings

    @overlay_settings.setter
    def overlay_settings(self, overlay_settings):
        """Sets the overlay_settings of this InputSettings.


        :param overlay_settings: The overlay_settings of this InputSettings.  # noqa: E501
        :type: InputSettingsOverlaySettings
        """

        self._overlay_settings = overlay_settings

    @property
    def type(self):
        """Gets the type of this InputSettings.  # noqa: E501


        :return: The type of this InputSettings.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this InputSettings.


        :param type: The type of this InputSettings.  # noqa: E501
        :type: str
        """
        allowed_values = ["video", "audio", "text"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def text_type(self):
        """Gets the text_type of this InputSettings.  # noqa: E501


        :return: The text_type of this InputSettings.  # noqa: E501
        :rtype: str
        """
        return self._text_type

    @text_type.setter
    def text_type(self, text_type):
        """Sets the text_type of this InputSettings.


        :param text_type: The text_type of this InputSettings.  # noqa: E501
        :type: str
        """
        allowed_values = ["subtitles"]  # noqa: E501
        if text_type not in allowed_values:
            raise ValueError(
                "Invalid value for `text_type` ({0}), must be one of {1}"  # noqa: E501
                .format(text_type, allowed_values)
            )

        self._text_type = text_type

    @property
    def language_code(self):
        """Gets the language_code of this InputSettings.  # noqa: E501


        :return: The language_code of this InputSettings.  # noqa: E501
        :rtype: str
        """
        return self._language_code

    @language_code.setter
    def language_code(self, language_code):
        """Sets the language_code of this InputSettings.


        :param language_code: The language_code of this InputSettings.  # noqa: E501
        :type: str
        """

        self._language_code = language_code

    @property
    def name(self):
        """Gets the name of this InputSettings.  # noqa: E501


        :return: The name of this InputSettings.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InputSettings.


        :param name: The name of this InputSettings.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def closed_captions(self):
        """Gets the closed_captions of this InputSettings.  # noqa: E501


        :return: The closed_captions of this InputSettings.  # noqa: E501
        :rtype: bool
        """
        return self._closed_captions

    @closed_captions.setter
    def closed_captions(self, closed_captions):
        """Sets the closed_captions of this InputSettings.


        :param closed_captions: The closed_captions of this InputSettings.  # noqa: E501
        :type: bool
        """

        self._closed_captions = closed_captions

    @property
    def passthrough(self):
        """Gets the passthrough of this InputSettings.  # noqa: E501


        :return: The passthrough of this InputSettings.  # noqa: E501
        :rtype: str
        """
        return self._passthrough

    @passthrough.setter
    def passthrough(self, passthrough):
        """Sets the passthrough of this InputSettings.


        :param passthrough: The passthrough of this InputSettings.  # noqa: E501
        :type: str
        """

        self._passthrough = passthrough

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InputSettings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
Mux Python - Copyright 2019 Mux Inc.

NOTE: This class is auto generated. Do not edit the class manually.
"""


import pprint
import re  # noqa: F401
import six

class SimulcastTarget(object):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'passthrough': 'str',
        'status': 'str',
        'stream_key': 'str',
        'url': 'str'
    }

    attribute_map = {
        'id': 'id',
        'passthrough': 'passthrough',
        'status': 'status',
        'stream_key': 'stream_key',
        'url': 'url'
    }

    def __init__(self, id=None, passthrough=None, status=None, stream_key=None, url=None):  # noqa: E501
        """SimulcastTarget - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._passthrough = None
        self._status = None
        self._stream_key = None
        self._url = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if passthrough is not None:
            self.passthrough = passthrough
        if status is not None:
            self.status = status
        if stream_key is not None:
            self.stream_key = stream_key
        if url is not None:
            self.url = url

    @property
    def id(self):
        """Gets the id of this SimulcastTarget.  # noqa: E501

        ID of the Simulcast Target  # noqa: E501

        :return: The id of this SimulcastTarget.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SimulcastTarget.

        ID of the Simulcast Target  # noqa: E501

        :param id: The id of this SimulcastTarget.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def passthrough(self):
        """Gets the passthrough of this SimulcastTarget.  # noqa: E501

        Arbitrary Metadata set when creating a simulcast target.  # noqa: E501

        :return: The passthrough of this SimulcastTarget.  # noqa: E501
        :rtype: str
        """
        return self._passthrough

    @passthrough.setter
    def passthrough(self, passthrough):
        """Sets the passthrough of this SimulcastTarget.

        Arbitrary Metadata set when creating a simulcast target.  # noqa: E501

        :param passthrough: The passthrough of this SimulcastTarget.  # noqa: E501
        :type: str
        """

        self._passthrough = passthrough

    @property
    def status(self):
        """Gets the status of this SimulcastTarget.  # noqa: E501

        The current status of the simulcast target. See Statuses below for detailed description.   * `idle`: Default status. When the parent live stream is in disconnected status, simulcast targets will be idle state.   * `starting`: The simulcast target transitions into this state when the parent live stream transition into connected state.   * `broadcasting`: The simulcast target has successfully connected to the third party live streaming service and is pushing video to that service.   * `errored`: The simulcast target encountered an error either while attempting to connect to the third party live streaming service, or mid-broadcasting. Compared to other errored statuses in the Mux Video API, a simulcast may transition back into the broadcasting state if a connection with the service can be re-established.   # noqa: E501

        :return: The status of this SimulcastTarget.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this SimulcastTarget.

        The current status of the simulcast target. See Statuses below for detailed description.   * `idle`: Default status. When the parent live stream is in disconnected status, simulcast targets will be idle state.   * `starting`: The simulcast target transitions into this state when the parent live stream transition into connected state.   * `broadcasting`: The simulcast target has successfully connected to the third party live streaming service and is pushing video to that service.   * `errored`: The simulcast target encountered an error either while attempting to connect to the third party live streaming service, or mid-broadcasting. Compared to other errored statuses in the Mux Video API, a simulcast may transition back into the broadcasting state if a connection with the service can be re-established.   # noqa: E501

        :param status: The status of this SimulcastTarget.  # noqa: E501
        :type: str
        """
        allowed_values = ["idle", "starting", "broadcasting", "errored"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def stream_key(self):
        """Gets the stream_key of this SimulcastTarget.  # noqa: E501

        Stream Key represents an stream identifier for the third party live streaming service to simulcast the parent live stream too.  # noqa: E501

        :return: The stream_key of this SimulcastTarget.  # noqa: E501
        :rtype: str
        """
        return self._stream_key

    @stream_key.setter
    def stream_key(self, stream_key):
        """Sets the stream_key of this SimulcastTarget.

        Stream Key represents an stream identifier for the third party live streaming service to simulcast the parent live stream too.  # noqa: E501

        :param stream_key: The stream_key of this SimulcastTarget.  # noqa: E501
        :type: str
        """

        self._stream_key = stream_key

    @property
    def url(self):
        """Gets the url of this SimulcastTarget.  # noqa: E501

        RTMP hostname including the application name for the third party live streaming service.  # noqa: E501

        :return: The url of this SimulcastTarget.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this SimulcastTarget.

        RTMP hostname including the application name for the third party live streaming service.  # noqa: E501

        :param url: The url of this SimulcastTarget.  # noqa: E501
        :type: str
        """

        self._url = url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SimulcastTarget):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
Mux Python - Copyright 2019 Mux Inc.

NOTE: This class is auto generated. Do not edit the class manually.
"""


import pprint
import re  # noqa: F401
import six

class Asset(object):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'created_at': 'str',
        'deleted_at': 'str',
        'status': 'str',
        'duration': 'float',
        'max_stored_resolution': 'str',
        'max_stored_frame_rate': 'float',
        'aspect_ratio': 'str',
        'playback_ids': 'list[PlaybackID]',
        'tracks': 'list[Track]',
        'errors': 'AssetErrors',
        'per_title_encode': 'bool',
        'is_live': 'bool',
        'passthrough': 'str',
        'live_stream_id': 'str',
        'master': 'AssetMaster',
        'master_access': 'str',
        'mp4_support': 'str',
        'normalize_audio': 'bool',
        'static_renditions': 'AssetStaticRenditions',
        'recording_times': 'list[AssetRecordingTimes]',
        'non_standard_input_reasons': 'AssetNonStandardInputReasons',
        'test': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'created_at': 'created_at',
        'deleted_at': 'deleted_at',
        'status': 'status',
        'duration': 'duration',
        'max_stored_resolution': 'max_stored_resolution',
        'max_stored_frame_rate': 'max_stored_frame_rate',
        'aspect_ratio': 'aspect_ratio',
        'playback_ids': 'playback_ids',
        'tracks': 'tracks',
        'errors': 'errors',
        'per_title_encode': 'per_title_encode',
        'is_live': 'is_live',
        'passthrough': 'passthrough',
        'live_stream_id': 'live_stream_id',
        'master': 'master',
        'master_access': 'master_access',
        'mp4_support': 'mp4_support',
        'normalize_audio': 'normalize_audio',
        'static_renditions': 'static_renditions',
        'recording_times': 'recording_times',
        'non_standard_input_reasons': 'non_standard_input_reasons',
        'test': 'test'
    }

    def __init__(self, id=None, created_at=None, deleted_at=None, status=None, duration=None, max_stored_resolution=None, max_stored_frame_rate=None, aspect_ratio=None, playback_ids=None, tracks=None, errors=None, per_title_encode=None, is_live=None, passthrough=None, live_stream_id=None, master=None, master_access='none', mp4_support='none', normalize_audio=False, static_renditions=None, recording_times=None, non_standard_input_reasons=None, test=None):  # noqa: E501
        """Asset - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._created_at = None
        self._deleted_at = None
        self._status = None
        self._duration = None
        self._max_stored_resolution = None
        self._max_stored_frame_rate = None
        self._aspect_ratio = None
        self._playback_ids = None
        self._tracks = None
        self._errors = None
        self._per_title_encode = None
        self._is_live = None
        self._passthrough = None
        self._live_stream_id = None
        self._master = None
        self._master_access = None
        self._mp4_support = None
        self._normalize_audio = None
        self._static_renditions = None
        self._recording_times = None
        self._non_standard_input_reasons = None
        self._test = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if created_at is not None:
            self.created_at = created_at
        if deleted_at is not None:
            self.deleted_at = deleted_at
        if status is not None:
            self.status = status
        if duration is not None:
            self.duration = duration
        if max_stored_resolution is not None:
            self.max_stored_resolution = max_stored_resolution
        if max_stored_frame_rate is not None:
            self.max_stored_frame_rate = max_stored_frame_rate
        if aspect_ratio is not None:
            self.aspect_ratio = aspect_ratio
        if playback_ids is not None:
            self.playback_ids = playback_ids
        if tracks is not None:
            self.tracks = tracks
        if errors is not None:
            self.errors = errors
        if per_title_encode is not None:
            self.per_title_encode = per_title_encode
        if is_live is not None:
            self.is_live = is_live
        if passthrough is not None:
            self.passthrough = passthrough
        if live_stream_id is not None:
            self.live_stream_id = live_stream_id
        if master is not None:
            self.master = master
        if master_access is not None:
            self.master_access = master_access
        if mp4_support is not None:
            self.mp4_support = mp4_support
        if normalize_audio is not None:
            self.normalize_audio = normalize_audio
        if static_renditions is not None:
            self.static_renditions = static_renditions
        if recording_times is not None:
            self.recording_times = recording_times
        if non_standard_input_reasons is not None:
            self.non_standard_input_reasons = non_standard_input_reasons
        if test is not None:
            self.test = test

    @property
    def id(self):
        """Gets the id of this Asset.  # noqa: E501


        :return: The id of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Asset.


        :param id: The id of this Asset.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def created_at(self):
        """Gets the created_at of this Asset.  # noqa: E501


        :return: The created_at of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Asset.


        :param created_at: The created_at of this Asset.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def deleted_at(self):
        """Gets the deleted_at of this Asset.  # noqa: E501


        :return: The deleted_at of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._deleted_at

    @deleted_at.setter
    def deleted_at(self, deleted_at):
        """Sets the deleted_at of this Asset.


        :param deleted_at: The deleted_at of this Asset.  # noqa: E501
        :type: str
        """

        self._deleted_at = deleted_at

    @property
    def status(self):
        """Gets the status of this Asset.  # noqa: E501


        :return: The status of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Asset.


        :param status: The status of this Asset.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def duration(self):
        """Gets the duration of this Asset.  # noqa: E501


        :return: The duration of this Asset.  # noqa: E501
        :rtype: float
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this Asset.


        :param duration: The duration of this Asset.  # noqa: E501
        :type: float
        """

        self._duration = duration

    @property
    def max_stored_resolution(self):
        """Gets the max_stored_resolution of this Asset.  # noqa: E501


        :return: The max_stored_resolution of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._max_stored_resolution

    @max_stored_resolution.setter
    def max_stored_resolution(self, max_stored_resolution):
        """Sets the max_stored_resolution of this Asset.


        :param max_stored_resolution: The max_stored_resolution of this Asset.  # noqa: E501
        :type: str
        """

        self._max_stored_resolution = max_stored_resolution

    @property
    def max_stored_frame_rate(self):
        """Gets the max_stored_frame_rate of this Asset.  # noqa: E501


        :return: The max_stored_frame_rate of this Asset.  # noqa: E501
        :rtype: float
        """
        return self._max_stored_frame_rate

    @max_stored_frame_rate.setter
    def max_stored_frame_rate(self, max_stored_frame_rate):
        """Sets the max_stored_frame_rate of this Asset.


        :param max_stored_frame_rate: The max_stored_frame_rate of this Asset.  # noqa: E501
        :type: float
        """

        self._max_stored_frame_rate = max_stored_frame_rate

    @property
    def aspect_ratio(self):
        """Gets the aspect_ratio of this Asset.  # noqa: E501


        :return: The aspect_ratio of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._aspect_ratio

    @aspect_ratio.setter
    def aspect_ratio(self, aspect_ratio):
        """Sets the aspect_ratio of this Asset.


        :param aspect_ratio: The aspect_ratio of this Asset.  # noqa: E501
        :type: str
        """

        self._aspect_ratio = aspect_ratio

    @property
    def playback_ids(self):
        """Gets the playback_ids of this Asset.  # noqa: E501


        :return: The playback_ids of this Asset.  # noqa: E501
        :rtype: list[PlaybackID]
        """
        return self._playback_ids

    @playback_ids.setter
    def playback_ids(self, playback_ids):
        """Sets the playback_ids of this Asset.


        :param playback_ids: The playback_ids of this Asset.  # noqa: E501
        :type: list[PlaybackID]
        """

        self._playback_ids = playback_ids

    @property
    def tracks(self):
        """Gets the tracks of this Asset.  # noqa: E501


        :return: The tracks of this Asset.  # noqa: E501
        :rtype: list[Track]
        """
        return self._tracks

    @tracks.setter
    def tracks(self, tracks):
        """Sets the tracks of this Asset.


        :param tracks: The tracks of this Asset.  # noqa: E501
        :type: list[Track]
        """

        self._tracks = tracks

    @property
    def errors(self):
        """Gets the errors of this Asset.  # noqa: E501


        :return: The errors of this Asset.  # noqa: E501
        :rtype: AssetErrors
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this Asset.


        :param errors: The errors of this Asset.  # noqa: E501
        :type: AssetErrors
        """

        self._errors = errors

    @property
    def per_title_encode(self):
        """Gets the per_title_encode of this Asset.  # noqa: E501


        :return: The per_title_encode of this Asset.  # noqa: E501
        :rtype: bool
        """
        return self._per_title_encode

    @per_title_encode.setter
    def per_title_encode(self, per_title_encode):
        """Sets the per_title_encode of this Asset.


        :param per_title_encode: The per_title_encode of this Asset.  # noqa: E501
        :type: bool
        """

        self._per_title_encode = per_title_encode

    @property
    def is_live(self):
        """Gets the is_live of this Asset.  # noqa: E501


        :return: The is_live of this Asset.  # noqa: E501
        :rtype: bool
        """
        return self._is_live

    @is_live.setter
    def is_live(self, is_live):
        """Sets the is_live of this Asset.


        :param is_live: The is_live of this Asset.  # noqa: E501
        :type: bool
        """

        self._is_live = is_live

    @property
    def passthrough(self):
        """Gets the passthrough of this Asset.  # noqa: E501


        :return: The passthrough of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._passthrough

    @passthrough.setter
    def passthrough(self, passthrough):
        """Sets the passthrough of this Asset.


        :param passthrough: The passthrough of this Asset.  # noqa: E501
        :type: str
        """

        self._passthrough = passthrough

    @property
    def live_stream_id(self):
        """Gets the live_stream_id of this Asset.  # noqa: E501


        :return: The live_stream_id of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._live_stream_id

    @live_stream_id.setter
    def live_stream_id(self, live_stream_id):
        """Sets the live_stream_id of this Asset.


        :param live_stream_id: The live_stream_id of this Asset.  # noqa: E501
        :type: str
        """

        self._live_stream_id = live_stream_id

    @property
    def master(self):
        """Gets the master of this Asset.  # noqa: E501


        :return: The master of this Asset.  # noqa: E501
        :rtype: AssetMaster
        """
        return self._master

    @master.setter
    def master(self, master):
        """Sets the master of this Asset.


        :param master: The master of this Asset.  # noqa: E501
        :type: AssetMaster
        """

        self._master = master

    @property
    def master_access(self):
        """Gets the master_access of this Asset.  # noqa: E501


        :return: The master_access of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._master_access

    @master_access.setter
    def master_access(self, master_access):
        """Sets the master_access of this Asset.


        :param master_access: The master_access of this Asset.  # noqa: E501
        :type: str
        """
        allowed_values = ["temporary", "none"]  # noqa: E501
        if master_access not in allowed_values:
            raise ValueError(
                "Invalid value for `master_access` ({0}), must be one of {1}"  # noqa: E501
                .format(master_access, allowed_values)
            )

        self._master_access = master_access

    @property
    def mp4_support(self):
        """Gets the mp4_support of this Asset.  # noqa: E501


        :return: The mp4_support of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._mp4_support

    @mp4_support.setter
    def mp4_support(self, mp4_support):
        """Sets the mp4_support of this Asset.


        :param mp4_support: The mp4_support of this Asset.  # noqa: E501
        :type: str
        """
        allowed_values = ["standard", "none"]  # noqa: E501
        if mp4_support not in allowed_values:
            raise ValueError(
                "Invalid value for `mp4_support` ({0}), must be one of {1}"  # noqa: E501
                .format(mp4_support, allowed_values)
            )

        self._mp4_support = mp4_support

    @property
    def normalize_audio(self):
        """Gets the normalize_audio of this Asset.  # noqa: E501


        :return: The normalize_audio of this Asset.  # noqa: E501
        :rtype: bool
        """
        return self._normalize_audio

    @normalize_audio.setter
    def normalize_audio(self, normalize_audio):
        """Sets the normalize_audio of this Asset.


        :param normalize_audio: The normalize_audio of this Asset.  # noqa: E501
        :type: bool
        """

        self._normalize_audio = normalize_audio

    @property
    def static_renditions(self):
        """Gets the static_renditions of this Asset.  # noqa: E501


        :return: The static_renditions of this Asset.  # noqa: E501
        :rtype: AssetStaticRenditions
        """
        return self._static_renditions

    @static_renditions.setter
    def static_renditions(self, static_renditions):
        """Sets the static_renditions of this Asset.


        :param static_renditions: The static_renditions of this Asset.  # noqa: E501
        :type: AssetStaticRenditions
        """

        self._static_renditions = static_renditions

    @property
    def recording_times(self):
        """Gets the recording_times of this Asset.  # noqa: E501

        An array of individual live stream recording sessions. A recording session is created on each encoder connection during the live stream  # noqa: E501

        :return: The recording_times of this Asset.  # noqa: E501
        :rtype: list[AssetRecordingTimes]
        """
        return self._recording_times

    @recording_times.setter
    def recording_times(self, recording_times):
        """Sets the recording_times of this Asset.

        An array of individual live stream recording sessions. A recording session is created on each encoder connection during the live stream  # noqa: E501

        :param recording_times: The recording_times of this Asset.  # noqa: E501
        :type: list[AssetRecordingTimes]
        """

        self._recording_times = recording_times

    @property
    def non_standard_input_reasons(self):
        """Gets the non_standard_input_reasons of this Asset.  # noqa: E501


        :return: The non_standard_input_reasons of this Asset.  # noqa: E501
        :rtype: AssetNonStandardInputReasons
        """
        return self._non_standard_input_reasons

    @non_standard_input_reasons.setter
    def non_standard_input_reasons(self, non_standard_input_reasons):
        """Sets the non_standard_input_reasons of this Asset.


        :param non_standard_input_reasons: The non_standard_input_reasons of this Asset.  # noqa: E501
        :type: AssetNonStandardInputReasons
        """

        self._non_standard_input_reasons = non_standard_input_reasons

    @property
    def test(self):
        """Gets the test of this Asset.  # noqa: E501


        :return: The test of this Asset.  # noqa: E501
        :rtype: bool
        """
        return self._test

    @test.setter
    def test(self, test):
        """Sets the test of this Asset.


        :param test: The test of this Asset.  # noqa: E501
        :type: bool
        """

        self._test = test

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Asset):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
Mux Python - Copyright 2019 Mux Inc.

NOTE: This class is auto generated. Do not edit the class manually.
"""


import pprint
import re  # noqa: F401
import six

class CreateAssetRequest(object):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'input': 'list[InputSettings]',
        'playback_policy': 'list[PlaybackPolicy]',
        'per_title_encode': 'bool',
        'passthrough': 'str',
        'mp4_support': 'str',
        'normalize_audio': 'bool',
        'master_access': 'str',
        'test': 'bool'
    }

    attribute_map = {
        'input': 'input',
        'playback_policy': 'playback_policy',
        'per_title_encode': 'per_title_encode',
        'passthrough': 'passthrough',
        'mp4_support': 'mp4_support',
        'normalize_audio': 'normalize_audio',
        'master_access': 'master_access',
        'test': 'test'
    }

    def __init__(self, input=None, playback_policy=None, per_title_encode=None, passthrough=None, mp4_support=None, normalize_audio=False, master_access=None, test=None):  # noqa: E501
        """CreateAssetRequest - a model defined in OpenAPI"""  # noqa: E501

        self._input = None
        self._playback_policy = None
        self._per_title_encode = None
        self._passthrough = None
        self._mp4_support = None
        self._normalize_audio = None
        self._master_access = None
        self._test = None
        self.discriminator = None

        if input is not None:
            self.input = input
        if playback_policy is not None:
            self.playback_policy = playback_policy
        if per_title_encode is not None:
            self.per_title_encode = per_title_encode
        if passthrough is not None:
            self.passthrough = passthrough
        if mp4_support is not None:
            self.mp4_support = mp4_support
        if normalize_audio is not None:
            self.normalize_audio = normalize_audio
        if master_access is not None:
            self.master_access = master_access
        if test is not None:
            self.test = test

    @property
    def input(self):
        """Gets the input of this CreateAssetRequest.  # noqa: E501


        :return: The input of this CreateAssetRequest.  # noqa: E501
        :rtype: list[InputSettings]
        """
        return self._input

    @input.setter
    def input(self, input):
        """Sets the input of this CreateAssetRequest.


        :param input: The input of this CreateAssetRequest.  # noqa: E501
        :type: list[InputSettings]
        """

        self._input = input

    @property
    def playback_policy(self):
        """Gets the playback_policy of this CreateAssetRequest.  # noqa: E501


        :return: The playback_policy of this CreateAssetRequest.  # noqa: E501
        :rtype: list[PlaybackPolicy]
        """
        return self._playback_policy

    @playback_policy.setter
    def playback_policy(self, playback_policy):
        """Sets the playback_policy of this CreateAssetRequest.


        :param playback_policy: The playback_policy of this CreateAssetRequest.  # noqa: E501
        :type: list[PlaybackPolicy]
        """

        self._playback_policy = playback_policy

    @property
    def per_title_encode(self):
        """Gets the per_title_encode of this CreateAssetRequest.  # noqa: E501


        :return: The per_title_encode of this CreateAssetRequest.  # noqa: E501
        :rtype: bool
        """
        return self._per_title_encode

    @per_title_encode.setter
    def per_title_encode(self, per_title_encode):
        """Sets the per_title_encode of this CreateAssetRequest.


        :param per_title_encode: The per_title_encode of this CreateAssetRequest.  # noqa: E501
        :type: bool
        """

        self._per_title_encode = per_title_encode

    @property
    def passthrough(self):
        """Gets the passthrough of this CreateAssetRequest.  # noqa: E501


        :return: The passthrough of this CreateAssetRequest.  # noqa: E501
        :rtype: str
        """
        return self._passthrough

    @passthrough.setter
    def passthrough(self, passthrough):
        """Sets the passthrough of this CreateAssetRequest.


        :param passthrough: The passthrough of this CreateAssetRequest.  # noqa: E501
        :type: str
        """

        self._passthrough = passthrough

    @property
    def mp4_support(self):
        """Gets the mp4_support of this CreateAssetRequest.  # noqa: E501


        :return: The mp4_support of this CreateAssetRequest.  # noqa: E501
        :rtype: str
        """
        return self._mp4_support

    @mp4_support.setter
    def mp4_support(self, mp4_support):
        """Sets the mp4_support of this CreateAssetRequest.


        :param mp4_support: The mp4_support of this CreateAssetRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["none", "standard"]  # noqa: E501
        if mp4_support not in allowed_values:
            raise ValueError(
                "Invalid value for `mp4_support` ({0}), must be one of {1}"  # noqa: E501
                .format(mp4_support, allowed_values)
            )

        self._mp4_support = mp4_support

    @property
    def normalize_audio(self):
        """Gets the normalize_audio of this CreateAssetRequest.  # noqa: E501

        Normalize the audio track loudness level. This parameter is only applicable to on-demand (not live) assets.  # noqa: E501

        :return: The normalize_audio of this CreateAssetRequest.  # noqa: E501
        :rtype: bool
        """
        return self._normalize_audio

    @normalize_audio.setter
    def normalize_audio(self, normalize_audio):
        """Sets the normalize_audio of this CreateAssetRequest.

        Normalize the audio track loudness level. This parameter is only applicable to on-demand (not live) assets.  # noqa: E501

        :param normalize_audio: The normalize_audio of this CreateAssetRequest.  # noqa: E501
        :type: bool
        """

        self._normalize_audio = normalize_audio

    @property
    def master_access(self):
        """Gets the master_access of this CreateAssetRequest.  # noqa: E501


        :return: The master_access of this CreateAssetRequest.  # noqa: E501
        :rtype: str
        """
        return self._master_access

    @master_access.setter
    def master_access(self, master_access):
        """Sets the master_access of this CreateAssetRequest.


        :param master_access: The master_access of this CreateAssetRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["none", "temporary"]  # noqa: E501
        if master_access not in allowed_values:
            raise ValueError(
                "Invalid value for `master_access` ({0}), must be one of {1}"  # noqa: E501
                .format(master_access, allowed_values)
            )

        self._master_access = master_access

    @property
    def test(self):
        """Gets the test of this CreateAssetRequest.  # noqa: E501


        :return: The test of this CreateAssetRequest.  # noqa: E501
        :rtype: bool
        """
        return self._test

    @test.setter
    def test(self, test):
        """Sets the test of this CreateAssetRequest.


        :param test: The test of this CreateAssetRequest.  # noqa: E501
        :type: bool
        """

        self._test = test

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateAssetRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
Mux Python - Copyright 2019 Mux Inc.

NOTE: This class is auto generated. Do not edit the class manually.
"""


import pprint
import re  # noqa: F401
import six

class DeliveryReport(object):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'live_stream_id': 'str',
        'asset_id': 'str',
        'passthrough': 'str',
        'created_at': 'str',
        'asset_state': 'str',
        'asset_duration': 'float',
        'delivered_seconds': 'float'
    }

    attribute_map = {
        'live_stream_id': 'live_stream_id',
        'asset_id': 'asset_id',
        'passthrough': 'passthrough',
        'created_at': 'created_at',
        'asset_state': 'asset_state',
        'asset_duration': 'asset_duration',
        'delivered_seconds': 'delivered_seconds'
    }

    def __init__(self, live_stream_id=None, asset_id=None, passthrough=None, created_at=None, asset_state=None, asset_duration=None, delivered_seconds=None):  # noqa: E501
        """DeliveryReport - a model defined in OpenAPI"""  # noqa: E501

        self._live_stream_id = None
        self._asset_id = None
        self._passthrough = None
        self._created_at = None
        self._asset_state = None
        self._asset_duration = None
        self._delivered_seconds = None
        self.discriminator = None

        if live_stream_id is not None:
            self.live_stream_id = live_stream_id
        if asset_id is not None:
            self.asset_id = asset_id
        if passthrough is not None:
            self.passthrough = passthrough
        if created_at is not None:
            self.created_at = created_at
        if asset_state is not None:
            self.asset_state = asset_state
        if asset_duration is not None:
            self.asset_duration = asset_duration
        if delivered_seconds is not None:
            self.delivered_seconds = delivered_seconds

    @property
    def live_stream_id(self):
        """Gets the live_stream_id of this DeliveryReport.  # noqa: E501


        :return: The live_stream_id of this DeliveryReport.  # noqa: E501
        :rtype: str
        """
        return self._live_stream_id

    @live_stream_id.setter
    def live_stream_id(self, live_stream_id):
        """Sets the live_stream_id of this DeliveryReport.


        :param live_stream_id: The live_stream_id of this DeliveryReport.  # noqa: E501
        :type: str
        """

        self._live_stream_id = live_stream_id

    @property
    def asset_id(self):
        """Gets the asset_id of this DeliveryReport.  # noqa: E501


        :return: The asset_id of this DeliveryReport.  # noqa: E501
        :rtype: str
        """
        return self._asset_id

    @asset_id.setter
    def asset_id(self, asset_id):
        """Sets the asset_id of this DeliveryReport.


        :param asset_id: The asset_id of this DeliveryReport.  # noqa: E501
        :type: str
        """

        self._asset_id = asset_id

    @property
    def passthrough(self):
        """Gets the passthrough of this DeliveryReport.  # noqa: E501


        :return: The passthrough of this DeliveryReport.  # noqa: E501
        :rtype: str
        """
        return self._passthrough

    @passthrough.setter
    def passthrough(self, passthrough):
        """Sets the passthrough of this DeliveryReport.


        :param passthrough: The passthrough of this DeliveryReport.  # noqa: E501
        :type: str
        """

        self._passthrough = passthrough

    @property
    def created_at(self):
        """Gets the created_at of this DeliveryReport.  # noqa: E501


        :return: The created_at of this DeliveryReport.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this DeliveryReport.


        :param created_at: The created_at of this DeliveryReport.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def asset_state(self):
        """Gets the asset_state of this DeliveryReport.  # noqa: E501


        :return: The asset_state of this DeliveryReport.  # noqa: E501
        :rtype: str
        """
        return self._asset_state

    @asset_state.setter
    def asset_state(self, asset_state):
        """Sets the asset_state of this DeliveryReport.


        :param asset_state: The asset_state of this DeliveryReport.  # noqa: E501
        :type: str
        """

        self._asset_state = asset_state

    @property
    def asset_duration(self):
        """Gets the asset_duration of this DeliveryReport.  # noqa: E501


        :return: The asset_duration of this DeliveryReport.  # noqa: E501
        :rtype: float
        """
        return self._asset_duration

    @asset_duration.setter
    def asset_duration(self, asset_duration):
        """Sets the asset_duration of this DeliveryReport.


        :param asset_duration: The asset_duration of this DeliveryReport.  # noqa: E501
        :type: float
        """

        self._asset_duration = asset_duration

    @property
    def delivered_seconds(self):
        """Gets the delivered_seconds of this DeliveryReport.  # noqa: E501


        :return: The delivered_seconds of this DeliveryReport.  # noqa: E501
        :rtype: float
        """
        return self._delivered_seconds

    @delivered_seconds.setter
    def delivered_seconds(self, delivered_seconds):
        """Sets the delivered_seconds of this DeliveryReport.


        :param delivered_seconds: The delivered_seconds of this DeliveryReport.  # noqa: E501
        :type: float
        """

        self._delivered_seconds = delivered_seconds

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeliveryReport):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from mux_python.api.assets_api import AssetsApi
from mux_python.api.delivery_usage_api import DeliveryUsageApi
from mux_python.api.direct_uploads_api import DirectUploadsApi
from mux_python.api.errors_api import ErrorsApi
from mux_python.api.exports_api import ExportsApi
from mux_python.api.filters_api import FiltersApi
from mux_python.api.live_streams_api import LiveStreamsApi
from mux_python.api.metrics_api import MetricsApi
from mux_python.api.url_signing_keys_api import URLSigningKeysApi
from mux_python.api.video_views_api import VideoViewsApi



# coding: utf-8

# flake8: noqa

"""
Mux Python - Copyright 2019 Mux Inc.

NOTE: This class is auto generated. Do not edit the class manually.
"""


from __future__ import absolute_import

__version__ = "1.9.0"

# import apis into sdk package
from mux_python.api.assets_api import AssetsApi
from mux_python.api.delivery_usage_api import DeliveryUsageApi
from mux_python.api.direct_uploads_api import DirectUploadsApi
from mux_python.api.errors_api import ErrorsApi
from mux_python.api.exports_api import ExportsApi
from mux_python.api.filters_api import FiltersApi
from mux_python.api.live_streams_api import LiveStreamsApi
from mux_python.api.metrics_api import MetricsApi
from mux_python.api.url_signing_keys_api import URLSigningKeysApi
from mux_python.api.video_views_api import VideoViewsApi


# import ApiClient
from mux_python.api_client import ApiClient
from mux_python.configuration import Configuration

# import models into sdk package
from mux_python.models.abridged_video_view import AbridgedVideoView
from mux_python.models.asset import Asset
from mux_python.models.asset_errors import AssetErrors
from mux_python.models.asset_master import AssetMaster
from mux_python.models.asset_non_standard_input_reasons import AssetNonStandardInputReasons
from mux_python.models.asset_recording_times import AssetRecordingTimes
from mux_python.models.asset_response import AssetResponse
from mux_python.models.asset_static_renditions import AssetStaticRenditions
from mux_python.models.asset_static_renditions_files import AssetStaticRenditionsFiles
from mux_python.models.breakdown_value import BreakdownValue
from mux_python.models.create_asset_request import CreateAssetRequest
from mux_python.models.create_live_stream_request import CreateLiveStreamRequest
from mux_python.models.create_playback_id_request import CreatePlaybackIDRequest
from mux_python.models.create_playback_id_response import CreatePlaybackIDResponse
from mux_python.models.create_simulcast_target_request import CreateSimulcastTargetRequest
from mux_python.models.create_track_request import CreateTrackRequest
from mux_python.models.create_track_response import CreateTrackResponse
from mux_python.models.create_upload_request import CreateUploadRequest
from mux_python.models.delivery_report import DeliveryReport
from mux_python.models.disable_live_stream_response import DisableLiveStreamResponse
from mux_python.models.enable_live_stream_response import EnableLiveStreamResponse
from mux_python.models.error import Error
from mux_python.models.filter_value import FilterValue
from mux_python.models.get_asset_input_info_response import GetAssetInputInfoResponse
from mux_python.models.get_asset_playback_id_response import GetAssetPlaybackIDResponse
from mux_python.models.get_metric_timeseries_data_response import GetMetricTimeseriesDataResponse
from mux_python.models.get_overall_values_response import GetOverallValuesResponse
from mux_python.models.input_file import InputFile
from mux_python.models.input_info import InputInfo
from mux_python.models.input_settings import InputSettings
from mux_python.models.input_settings_overlay_settings import InputSettingsOverlaySettings
from mux_python.models.input_track import InputTrack
from mux_python.models.insight import Insight
from mux_python.models.list_all_metric_values_response import ListAllMetricValuesResponse
from mux_python.models.list_assets_response import ListAssetsResponse
from mux_python.models.list_breakdown_values_response import ListBreakdownValuesResponse
from mux_python.models.list_delivery_usage_response import ListDeliveryUsageResponse
from mux_python.models.list_errors_response import ListErrorsResponse
from mux_python.models.list_exports_response import ListExportsResponse
from mux_python.models.list_filter_values_response import ListFilterValuesResponse
from mux_python.models.list_filters_response import ListFiltersResponse
from mux_python.models.list_filters_response_data import ListFiltersResponseData
from mux_python.models.list_insights_response import ListInsightsResponse
from mux_python.models.list_live_streams_response import ListLiveStreamsResponse
from mux_python.models.list_signing_keys_response import ListSigningKeysResponse
from mux_python.models.list_uploads_response import ListUploadsResponse
from mux_python.models.list_video_views_response import ListVideoViewsResponse
from mux_python.models.live_stream import LiveStream
from mux_python.models.live_stream_response import LiveStreamResponse
from mux_python.models.metric import Metric
from mux_python.models.overall_values import OverallValues
from mux_python.models.playback_id import PlaybackID
from mux_python.models.playback_policy import PlaybackPolicy
from mux_python.models.score import Score
from mux_python.models.signal_live_stream_complete_response import SignalLiveStreamCompleteResponse
from mux_python.models.signing_key import SigningKey
from mux_python.models.signing_key_response import SigningKeyResponse
from mux_python.models.simulcast_target import SimulcastTarget
from mux_python.models.simulcast_target_response import SimulcastTargetResponse
from mux_python.models.track import Track
from mux_python.models.update_asset_mp4_support_request import UpdateAssetMP4SupportRequest
from mux_python.models.update_asset_master_access_request import UpdateAssetMasterAccessRequest
from mux_python.models.upload import Upload
from mux_python.models.upload_error import UploadError
from mux_python.models.upload_response import UploadResponse
from mux_python.models.video_view import VideoView
from mux_python.models.video_view_event import VideoViewEvent
from mux_python.models.video_view_response import VideoViewResponse



# coding: utf-8

"""
Mux Python - Copyright 2019 Mux Inc.

NOTE: This class is auto generated. Do not edit the class manually.
"""


import pprint
import re  # noqa: F401
import six

class Insight(object):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'total_watch_time': 'int',
        'total_views': 'int',
        'negative_impact_score': 'float',
        'metric': 'float',
        'filter_value': 'str',
        'filter_column': 'str'
    }

    attribute_map = {
        'total_watch_time': 'total_watch_time',
        'total_views': 'total_views',
        'negative_impact_score': 'negative_impact_score',
        'metric': 'metric',
        'filter_value': 'filter_value',
        'filter_column': 'filter_column'
    }

    def __init__(self, total_watch_time=None, total_views=None, negative_impact_score=None, metric=None, filter_value=None, filter_column=None):  # noqa: E501
        """Insight - a model defined in OpenAPI"""  # noqa: E501

        self._total_watch_time = None
        self._total_views = None
        self._negative_impact_score = None
        self._metric = None
        self._filter_value = None
        self._filter_column = None
        self.discriminator = None

        if total_watch_time is not None:
            self.total_watch_time = total_watch_time
        if total_views is not None:
            self.total_views = total_views
        if negative_impact_score is not None:
            self.negative_impact_score = negative_impact_score
        if metric is not None:
            self.metric = metric
        if filter_value is not None:
            self.filter_value = filter_value
        if filter_column is not None:
            self.filter_column = filter_column

    @property
    def total_watch_time(self):
        """Gets the total_watch_time of this Insight.  # noqa: E501


        :return: The total_watch_time of this Insight.  # noqa: E501
        :rtype: int
        """
        return self._total_watch_time

    @total_watch_time.setter
    def total_watch_time(self, total_watch_time):
        """Sets the total_watch_time of this Insight.


        :param total_watch_time: The total_watch_time of this Insight.  # noqa: E501
        :type: int
        """

        self._total_watch_time = total_watch_time

    @property
    def total_views(self):
        """Gets the total_views of this Insight.  # noqa: E501


        :return: The total_views of this Insight.  # noqa: E501
        :rtype: int
        """
        return self._total_views

    @total_views.setter
    def total_views(self, total_views):
        """Sets the total_views of this Insight.


        :param total_views: The total_views of this Insight.  # noqa: E501
        :type: int
        """

        self._total_views = total_views

    @property
    def negative_impact_score(self):
        """Gets the negative_impact_score of this Insight.  # noqa: E501


        :return: The negative_impact_score of this Insight.  # noqa: E501
        :rtype: float
        """
        return self._negative_impact_score

    @negative_impact_score.setter
    def negative_impact_score(self, negative_impact_score):
        """Sets the negative_impact_score of this Insight.


        :param negative_impact_score: The negative_impact_score of this Insight.  # noqa: E501
        :type: float
        """

        self._negative_impact_score = negative_impact_score

    @property
    def metric(self):
        """Gets the metric of this Insight.  # noqa: E501


        :return: The metric of this Insight.  # noqa: E501
        :rtype: float
        """
        return self._metric

    @metric.setter
    def metric(self, metric):
        """Sets the metric of this Insight.


        :param metric: The metric of this Insight.  # noqa: E501
        :type: float
        """

        self._metric = metric

    @property
    def filter_value(self):
        """Gets the filter_value of this Insight.  # noqa: E501


        :return: The filter_value of this Insight.  # noqa: E501
        :rtype: str
        """
        return self._filter_value

    @filter_value.setter
    def filter_value(self, filter_value):
        """Sets the filter_value of this Insight.


        :param filter_value: The filter_value of this Insight.  # noqa: E501
        :type: str
        """

        self._filter_value = filter_value

    @property
    def filter_column(self):
        """Gets the filter_column of this Insight.  # noqa: E501


        :return: The filter_column of this Insight.  # noqa: E501
        :rtype: str
        """
        return self._filter_column

    @filter_column.setter
    def filter_column(self, filter_column):
        """Sets the filter_column of this Insight.


        :param filter_column: The filter_column of this Insight.  # noqa: E501
        :type: str
        """

        self._filter_column = filter_column

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Insight):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
Mux Python - Copyright 2019 Mux Inc.

NOTE: This class is auto generated. Do not edit the class manually.
"""


import pprint
import re  # noqa: F401
import six

class AssetMaster(object):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'status': 'str',
        'url': 'str'
    }

    attribute_map = {
        'status': 'status',
        'url': 'url'
    }

    def __init__(self, status=None, url=None):  # noqa: E501
        """AssetMaster - a model defined in OpenAPI"""  # noqa: E501

        self._status = None
        self._url = None
        self.discriminator = None

        if status is not None:
            self.status = status
        if url is not None:
            self.url = url

    @property
    def status(self):
        """Gets the status of this AssetMaster.  # noqa: E501


        :return: The status of this AssetMaster.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this AssetMaster.


        :param status: The status of this AssetMaster.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def url(self):
        """Gets the url of this AssetMaster.  # noqa: E501


        :return: The url of this AssetMaster.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this AssetMaster.


        :param url: The url of this AssetMaster.  # noqa: E501
        :type: str
        """

        self._url = url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssetMaster):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
Mux Python - Copyright 2019 Mux Inc.

NOTE: This class is auto generated. Do not edit the class manually.
"""


import pprint
import re  # noqa: F401
import six

class InputSettingsOverlaySettings(object):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'vertical_align': 'str',
        'vertical_margin': 'str',
        'horizontal_align': 'str',
        'horizontal_margin': 'str',
        'width': 'str',
        'height': 'str',
        'opacity': 'str'
    }

    attribute_map = {
        'vertical_align': 'vertical_align',
        'vertical_margin': 'vertical_margin',
        'horizontal_align': 'horizontal_align',
        'horizontal_margin': 'horizontal_margin',
        'width': 'width',
        'height': 'height',
        'opacity': 'opacity'
    }

    def __init__(self, vertical_align=None, vertical_margin=None, horizontal_align=None, horizontal_margin=None, width=None, height=None, opacity=None):  # noqa: E501
        """InputSettingsOverlaySettings - a model defined in OpenAPI"""  # noqa: E501

        self._vertical_align = None
        self._vertical_margin = None
        self._horizontal_align = None
        self._horizontal_margin = None
        self._width = None
        self._height = None
        self._opacity = None
        self.discriminator = None

        if vertical_align is not None:
            self.vertical_align = vertical_align
        if vertical_margin is not None:
            self.vertical_margin = vertical_margin
        if horizontal_align is not None:
            self.horizontal_align = horizontal_align
        if horizontal_margin is not None:
            self.horizontal_margin = horizontal_margin
        if width is not None:
            self.width = width
        if height is not None:
            self.height = height
        if opacity is not None:
            self.opacity = opacity

    @property
    def vertical_align(self):
        """Gets the vertical_align of this InputSettingsOverlaySettings.  # noqa: E501


        :return: The vertical_align of this InputSettingsOverlaySettings.  # noqa: E501
        :rtype: str
        """
        return self._vertical_align

    @vertical_align.setter
    def vertical_align(self, vertical_align):
        """Sets the vertical_align of this InputSettingsOverlaySettings.


        :param vertical_align: The vertical_align of this InputSettingsOverlaySettings.  # noqa: E501
        :type: str
        """
        allowed_values = ["top", "middle", "bottom"]  # noqa: E501
        if vertical_align not in allowed_values:
            raise ValueError(
                "Invalid value for `vertical_align` ({0}), must be one of {1}"  # noqa: E501
                .format(vertical_align, allowed_values)
            )

        self._vertical_align = vertical_align

    @property
    def vertical_margin(self):
        """Gets the vertical_margin of this InputSettingsOverlaySettings.  # noqa: E501


        :return: The vertical_margin of this InputSettingsOverlaySettings.  # noqa: E501
        :rtype: str
        """
        return self._vertical_margin

    @vertical_margin.setter
    def vertical_margin(self, vertical_margin):
        """Sets the vertical_margin of this InputSettingsOverlaySettings.


        :param vertical_margin: The vertical_margin of this InputSettingsOverlaySettings.  # noqa: E501
        :type: str
        """

        self._vertical_margin = vertical_margin

    @property
    def horizontal_align(self):
        """Gets the horizontal_align of this InputSettingsOverlaySettings.  # noqa: E501


        :return: The horizontal_align of this InputSettingsOverlaySettings.  # noqa: E501
        :rtype: str
        """
        return self._horizontal_align

    @horizontal_align.setter
    def horizontal_align(self, horizontal_align):
        """Sets the horizontal_align of this InputSettingsOverlaySettings.


        :param horizontal_align: The horizontal_align of this InputSettingsOverlaySettings.  # noqa: E501
        :type: str
        """
        allowed_values = ["left", "center", "right"]  # noqa: E501
        if horizontal_align not in allowed_values:
            raise ValueError(
                "Invalid value for `horizontal_align` ({0}), must be one of {1}"  # noqa: E501
                .format(horizontal_align, allowed_values)
            )

        self._horizontal_align = horizontal_align

    @property
    def horizontal_margin(self):
        """Gets the horizontal_margin of this InputSettingsOverlaySettings.  # noqa: E501


        :return: The horizontal_margin of this InputSettingsOverlaySettings.  # noqa: E501
        :rtype: str
        """
        return self._horizontal_margin

    @horizontal_margin.setter
    def horizontal_margin(self, horizontal_margin):
        """Sets the horizontal_margin of this InputSettingsOverlaySettings.


        :param horizontal_margin: The horizontal_margin of this InputSettingsOverlaySettings.  # noqa: E501
        :type: str
        """

        self._horizontal_margin = horizontal_margin

    @property
    def width(self):
        """Gets the width of this InputSettingsOverlaySettings.  # noqa: E501


        :return: The width of this InputSettingsOverlaySettings.  # noqa: E501
        :rtype: str
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this InputSettingsOverlaySettings.


        :param width: The width of this InputSettingsOverlaySettings.  # noqa: E501
        :type: str
        """

        self._width = width

    @property
    def height(self):
        """Gets the height of this InputSettingsOverlaySettings.  # noqa: E501


        :return: The height of this InputSettingsOverlaySettings.  # noqa: E501
        :rtype: str
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this InputSettingsOverlaySettings.


        :param height: The height of this InputSettingsOverlaySettings.  # noqa: E501
        :type: str
        """

        self._height = height

    @property
    def opacity(self):
        """Gets the opacity of this InputSettingsOverlaySettings.  # noqa: E501


        :return: The opacity of this InputSettingsOverlaySettings.  # noqa: E501
        :rtype: str
        """
        return self._opacity

    @opacity.setter
    def opacity(self, opacity):
        """Sets the opacity of this InputSettingsOverlaySettings.


        :param opacity: The opacity of this InputSettingsOverlaySettings.  # noqa: E501
        :type: str
        """

        self._opacity = opacity

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InputSettingsOverlaySettings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
Mux Python - Copyright 2019 Mux Inc.

NOTE: This class is auto generated. Do not edit the class manually.
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from mux_python.api_client import ApiClient

class DirectUploadsApi(object):

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def cancel_direct_upload(self, upload_id, **kwargs):  # noqa: E501
        """Cancel a direct upload  # noqa: E501

        Cancels a direct upload and marks it as cancelled. If a pending upload finishes after this request, no asset will be created. This request will only succeed if the upload is still in the `waiting` state.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_direct_upload(upload_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str upload_id: ID of the Upload (required)
        :return: UploadResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cancel_direct_upload_with_http_info(upload_id, **kwargs)  # noqa: E501
        else:
            (data) = self.cancel_direct_upload_with_http_info(upload_id, **kwargs)  # noqa: E501
            return data

    def cancel_direct_upload_with_http_info(self, upload_id, **kwargs):  # noqa: E501
        """Cancel a direct upload  # noqa: E501

        Cancels a direct upload and marks it as cancelled. If a pending upload finishes after this request, no asset will be created. This request will only succeed if the upload is still in the `waiting` state.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_direct_upload_with_http_info(upload_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str upload_id: ID of the Upload (required)
        :return: UploadResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['upload_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cancel_direct_upload" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'upload_id' is set
        if ('upload_id' not in local_var_params or
                local_var_params['upload_id'] is None):
            raise ValueError("Missing the required parameter `upload_id` when calling `cancel_direct_upload`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'upload_id' in local_var_params:
            path_params['UPLOAD_ID'] = local_var_params['upload_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['accessToken']  # noqa: E501

        return self.api_client.call_api(
            '/video/v1/uploads/{UPLOAD_ID}/cancel', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UploadResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_direct_upload(self, create_upload_request, **kwargs):  # noqa: E501
        """Create a new direct upload URL  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_direct_upload(create_upload_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateUploadRequest create_upload_request: (required)
        :return: UploadResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_direct_upload_with_http_info(create_upload_request, **kwargs)  # noqa: E501
        else:
            (data) = self.create_direct_upload_with_http_info(create_upload_request, **kwargs)  # noqa: E501
            return data

    def create_direct_upload_with_http_info(self, create_upload_request, **kwargs):  # noqa: E501
        """Create a new direct upload URL  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_direct_upload_with_http_info(create_upload_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateUploadRequest create_upload_request: (required)
        :return: UploadResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['create_upload_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_direct_upload" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'create_upload_request' is set
        if ('create_upload_request' not in local_var_params or
                local_var_params['create_upload_request'] is None):
            raise ValueError("Missing the required parameter `create_upload_request` when calling `create_direct_upload`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_upload_request' in local_var_params:
            body_params = local_var_params['create_upload_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['accessToken']  # noqa: E501

        return self.api_client.call_api(
            '/video/v1/uploads', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UploadResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_direct_upload(self, upload_id, **kwargs):  # noqa: E501
        """Retrieve a single direct upload's info  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_direct_upload(upload_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str upload_id: ID of the Upload (required)
        :return: UploadResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_direct_upload_with_http_info(upload_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_direct_upload_with_http_info(upload_id, **kwargs)  # noqa: E501
            return data

    def get_direct_upload_with_http_info(self, upload_id, **kwargs):  # noqa: E501
        """Retrieve a single direct upload's info  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_direct_upload_with_http_info(upload_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str upload_id: ID of the Upload (required)
        :return: UploadResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['upload_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_direct_upload" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'upload_id' is set
        if ('upload_id' not in local_var_params or
                local_var_params['upload_id'] is None):
            raise ValueError("Missing the required parameter `upload_id` when calling `get_direct_upload`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'upload_id' in local_var_params:
            path_params['UPLOAD_ID'] = local_var_params['upload_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['accessToken']  # noqa: E501

        return self.api_client.call_api(
            '/video/v1/uploads/{UPLOAD_ID}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UploadResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_direct_uploads(self, **kwargs):  # noqa: E501
        """List direct uploads  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_direct_uploads(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int limit: Number of items to include in the response
        :param int page: Offset by this many pages, of the size of `limit`
        :return: ListUploadsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_direct_uploads_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.list_direct_uploads_with_http_info(**kwargs)  # noqa: E501
            return data

    def list_direct_uploads_with_http_info(self, **kwargs):  # noqa: E501
        """List direct uploads  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_direct_uploads_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int limit: Number of items to include in the response
        :param int page: Offset by this many pages, of the size of `limit`
        :return: ListUploadsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['limit', 'page']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_direct_uploads" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'limit' in local_var_params:
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'page' in local_var_params:
            query_params.append(('page', local_var_params['page']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['accessToken']  # noqa: E501

        return self.api_client.call_api(
            '/video/v1/uploads', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListUploadsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
Mux Python - Copyright 2019 Mux Inc.

NOTE: This class is auto generated. Do not edit the class manually.
"""


import pprint
import re  # noqa: F401
import six

class VideoViewEvent(object):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'viewer_time': 'int',
        'playback_time': 'int',
        'name': 'str',
        'event_time': 'int'
    }

    attribute_map = {
        'viewer_time': 'viewer_time',
        'playback_time': 'playback_time',
        'name': 'name',
        'event_time': 'event_time'
    }

    def __init__(self, viewer_time=None, playback_time=None, name=None, event_time=None):  # noqa: E501
        """VideoViewEvent - a model defined in OpenAPI"""  # noqa: E501

        self._viewer_time = None
        self._playback_time = None
        self._name = None
        self._event_time = None
        self.discriminator = None

        if viewer_time is not None:
            self.viewer_time = viewer_time
        if playback_time is not None:
            self.playback_time = playback_time
        if name is not None:
            self.name = name
        if event_time is not None:
            self.event_time = event_time

    @property
    def viewer_time(self):
        """Gets the viewer_time of this VideoViewEvent.  # noqa: E501


        :return: The viewer_time of this VideoViewEvent.  # noqa: E501
        :rtype: int
        """
        return self._viewer_time

    @viewer_time.setter
    def viewer_time(self, viewer_time):
        """Sets the viewer_time of this VideoViewEvent.


        :param viewer_time: The viewer_time of this VideoViewEvent.  # noqa: E501
        :type: int
        """

        self._viewer_time = viewer_time

    @property
    def playback_time(self):
        """Gets the playback_time of this VideoViewEvent.  # noqa: E501


        :return: The playback_time of this VideoViewEvent.  # noqa: E501
        :rtype: int
        """
        return self._playback_time

    @playback_time.setter
    def playback_time(self, playback_time):
        """Sets the playback_time of this VideoViewEvent.


        :param playback_time: The playback_time of this VideoViewEvent.  # noqa: E501
        :type: int
        """

        self._playback_time = playback_time

    @property
    def name(self):
        """Gets the name of this VideoViewEvent.  # noqa: E501


        :return: The name of this VideoViewEvent.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this VideoViewEvent.


        :param name: The name of this VideoViewEvent.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def event_time(self):
        """Gets the event_time of this VideoViewEvent.  # noqa: E501


        :return: The event_time of this VideoViewEvent.  # noqa: E501
        :rtype: int
        """
        return self._event_time

    @event_time.setter
    def event_time(self, event_time):
        """Sets the event_time of this VideoViewEvent.


        :param event_time: The event_time of this VideoViewEvent.  # noqa: E501
        :type: int
        """

        self._event_time = event_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VideoViewEvent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
Mux Python - Copyright 2019 Mux Inc.

NOTE: This class is auto generated. Do not edit the class manually.
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from mux_python.api_client import ApiClient

class AssetsApi(object):

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_asset(self, create_asset_request, **kwargs):  # noqa: E501
        """Create an asset  # noqa: E501

        Create a new Mux Video asset.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_asset(create_asset_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateAssetRequest create_asset_request: (required)
        :return: AssetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_asset_with_http_info(create_asset_request, **kwargs)  # noqa: E501
        else:
            (data) = self.create_asset_with_http_info(create_asset_request, **kwargs)  # noqa: E501
            return data

    def create_asset_with_http_info(self, create_asset_request, **kwargs):  # noqa: E501
        """Create an asset  # noqa: E501

        Create a new Mux Video asset.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_asset_with_http_info(create_asset_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateAssetRequest create_asset_request: (required)
        :return: AssetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['create_asset_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_asset" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'create_asset_request' is set
        if ('create_asset_request' not in local_var_params or
                local_var_params['create_asset_request'] is None):
            raise ValueError("Missing the required parameter `create_asset_request` when calling `create_asset`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_asset_request' in local_var_params:
            body_params = local_var_params['create_asset_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['accessToken']  # noqa: E501

        return self.api_client.call_api(
            '/video/v1/assets', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AssetResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_asset_playback_id(self, asset_id, create_playback_id_request, **kwargs):  # noqa: E501
        """Create a playback ID  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_asset_playback_id(asset_id, create_playback_id_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: The asset ID. (required)
        :param CreatePlaybackIDRequest create_playback_id_request: (required)
        :return: CreatePlaybackIDResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_asset_playback_id_with_http_info(asset_id, create_playback_id_request, **kwargs)  # noqa: E501
        else:
            (data) = self.create_asset_playback_id_with_http_info(asset_id, create_playback_id_request, **kwargs)  # noqa: E501
            return data

    def create_asset_playback_id_with_http_info(self, asset_id, create_playback_id_request, **kwargs):  # noqa: E501
        """Create a playback ID  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_asset_playback_id_with_http_info(asset_id, create_playback_id_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: The asset ID. (required)
        :param CreatePlaybackIDRequest create_playback_id_request: (required)
        :return: CreatePlaybackIDResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['asset_id', 'create_playback_id_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_asset_playback_id" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'asset_id' is set
        if ('asset_id' not in local_var_params or
                local_var_params['asset_id'] is None):
            raise ValueError("Missing the required parameter `asset_id` when calling `create_asset_playback_id`")  # noqa: E501
        # verify the required parameter 'create_playback_id_request' is set
        if ('create_playback_id_request' not in local_var_params or
                local_var_params['create_playback_id_request'] is None):
            raise ValueError("Missing the required parameter `create_playback_id_request` when calling `create_asset_playback_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'asset_id' in local_var_params:
            path_params['ASSET_ID'] = local_var_params['asset_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_playback_id_request' in local_var_params:
            body_params = local_var_params['create_playback_id_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['accessToken']  # noqa: E501

        return self.api_client.call_api(
            '/video/v1/assets/{ASSET_ID}/playback-ids', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreatePlaybackIDResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_asset_track(self, asset_id, create_track_request, **kwargs):  # noqa: E501
        """Create an asset track  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_asset_track(asset_id, create_track_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: The asset ID. (required)
        :param CreateTrackRequest create_track_request: (required)
        :return: CreateTrackResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_asset_track_with_http_info(asset_id, create_track_request, **kwargs)  # noqa: E501
        else:
            (data) = self.create_asset_track_with_http_info(asset_id, create_track_request, **kwargs)  # noqa: E501
            return data

    def create_asset_track_with_http_info(self, asset_id, create_track_request, **kwargs):  # noqa: E501
        """Create an asset track  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_asset_track_with_http_info(asset_id, create_track_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: The asset ID. (required)
        :param CreateTrackRequest create_track_request: (required)
        :return: CreateTrackResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['asset_id', 'create_track_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_asset_track" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'asset_id' is set
        if ('asset_id' not in local_var_params or
                local_var_params['asset_id'] is None):
            raise ValueError("Missing the required parameter `asset_id` when calling `create_asset_track`")  # noqa: E501
        # verify the required parameter 'create_track_request' is set
        if ('create_track_request' not in local_var_params or
                local_var_params['create_track_request'] is None):
            raise ValueError("Missing the required parameter `create_track_request` when calling `create_asset_track`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'asset_id' in local_var_params:
            path_params['ASSET_ID'] = local_var_params['asset_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_track_request' in local_var_params:
            body_params = local_var_params['create_track_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['accessToken']  # noqa: E501

        return self.api_client.call_api(
            '/video/v1/assets/{ASSET_ID}/tracks', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateTrackResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_asset(self, asset_id, **kwargs):  # noqa: E501
        """Delete an asset  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_asset(asset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: The asset ID. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_asset_with_http_info(asset_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_asset_with_http_info(asset_id, **kwargs)  # noqa: E501
            return data

    def delete_asset_with_http_info(self, asset_id, **kwargs):  # noqa: E501
        """Delete an asset  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_asset_with_http_info(asset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: The asset ID. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['asset_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_asset" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'asset_id' is set
        if ('asset_id' not in local_var_params or
                local_var_params['asset_id'] is None):
            raise ValueError("Missing the required parameter `asset_id` when calling `delete_asset`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'asset_id' in local_var_params:
            path_params['ASSET_ID'] = local_var_params['asset_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['accessToken']  # noqa: E501

        return self.api_client.call_api(
            '/video/v1/assets/{ASSET_ID}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_asset_playback_id(self, asset_id, playback_id, **kwargs):  # noqa: E501
        """Delete a playback ID  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_asset_playback_id(asset_id, playback_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: The asset ID. (required)
        :param str playback_id: The live stream's playback ID. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_asset_playback_id_with_http_info(asset_id, playback_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_asset_playback_id_with_http_info(asset_id, playback_id, **kwargs)  # noqa: E501
            return data

    def delete_asset_playback_id_with_http_info(self, asset_id, playback_id, **kwargs):  # noqa: E501
        """Delete a playback ID  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_asset_playback_id_with_http_info(asset_id, playback_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: The asset ID. (required)
        :param str playback_id: The live stream's playback ID. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['asset_id', 'playback_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_asset_playback_id" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'asset_id' is set
        if ('asset_id' not in local_var_params or
                local_var_params['asset_id'] is None):
            raise ValueError("Missing the required parameter `asset_id` when calling `delete_asset_playback_id`")  # noqa: E501
        # verify the required parameter 'playback_id' is set
        if ('playback_id' not in local_var_params or
                local_var_params['playback_id'] is None):
            raise ValueError("Missing the required parameter `playback_id` when calling `delete_asset_playback_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'asset_id' in local_var_params:
            path_params['ASSET_ID'] = local_var_params['asset_id']  # noqa: E501
        if 'playback_id' in local_var_params:
            path_params['PLAYBACK_ID'] = local_var_params['playback_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['accessToken']  # noqa: E501

        return self.api_client.call_api(
            '/video/v1/assets/{ASSET_ID}/playback-ids/{PLAYBACK_ID}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_asset_track(self, asset_id, track_id, **kwargs):  # noqa: E501
        """Delete an asset track  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_asset_track(asset_id, track_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: The asset ID. (required)
        :param str track_id: The track ID. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_asset_track_with_http_info(asset_id, track_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_asset_track_with_http_info(asset_id, track_id, **kwargs)  # noqa: E501
            return data

    def delete_asset_track_with_http_info(self, asset_id, track_id, **kwargs):  # noqa: E501
        """Delete an asset track  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_asset_track_with_http_info(asset_id, track_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: The asset ID. (required)
        :param str track_id: The track ID. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['asset_id', 'track_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_asset_track" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'asset_id' is set
        if ('asset_id' not in local_var_params or
                local_var_params['asset_id'] is None):
            raise ValueError("Missing the required parameter `asset_id` when calling `delete_asset_track`")  # noqa: E501
        # verify the required parameter 'track_id' is set
        if ('track_id' not in local_var_params or
                local_var_params['track_id'] is None):
            raise ValueError("Missing the required parameter `track_id` when calling `delete_asset_track`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'asset_id' in local_var_params:
            path_params['ASSET_ID'] = local_var_params['asset_id']  # noqa: E501
        if 'track_id' in local_var_params:
            path_params['TRACK_ID'] = local_var_params['track_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['accessToken']  # noqa: E501

        return self.api_client.call_api(
            '/video/v1/assets/{ASSET_ID}/tracks/{TRACK_ID}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_asset(self, asset_id, **kwargs):  # noqa: E501
        """Retrieve an asset  # noqa: E501

        Retrieves the details of an asset that has previously been created. Supply the unique asset ID that was returned from your previous request, and Mux will return the corresponding asset information. The same information is returned when creating an asset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_asset(asset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: The asset ID. (required)
        :return: AssetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_asset_with_http_info(asset_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_asset_with_http_info(asset_id, **kwargs)  # noqa: E501
            return data

    def get_asset_with_http_info(self, asset_id, **kwargs):  # noqa: E501
        """Retrieve an asset  # noqa: E501

        Retrieves the details of an asset that has previously been created. Supply the unique asset ID that was returned from your previous request, and Mux will return the corresponding asset information. The same information is returned when creating an asset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_asset_with_http_info(asset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: The asset ID. (required)
        :return: AssetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['asset_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_asset" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'asset_id' is set
        if ('asset_id' not in local_var_params or
                local_var_params['asset_id'] is None):
            raise ValueError("Missing the required parameter `asset_id` when calling `get_asset`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'asset_id' in local_var_params:
            path_params['ASSET_ID'] = local_var_params['asset_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['accessToken']  # noqa: E501

        return self.api_client.call_api(
            '/video/v1/assets/{ASSET_ID}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AssetResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_asset_input_info(self, asset_id, **kwargs):  # noqa: E501
        """Retrieve asset input info  # noqa: E501

        Returns a list of the input objects that were used to create the asset along with any settings that were applied to each input.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_asset_input_info(asset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: The asset ID. (required)
        :return: GetAssetInputInfoResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_asset_input_info_with_http_info(asset_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_asset_input_info_with_http_info(asset_id, **kwargs)  # noqa: E501
            return data

    def get_asset_input_info_with_http_info(self, asset_id, **kwargs):  # noqa: E501
        """Retrieve asset input info  # noqa: E501

        Returns a list of the input objects that were used to create the asset along with any settings that were applied to each input.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_asset_input_info_with_http_info(asset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: The asset ID. (required)
        :return: GetAssetInputInfoResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['asset_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_asset_input_info" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'asset_id' is set
        if ('asset_id' not in local_var_params or
                local_var_params['asset_id'] is None):
            raise ValueError("Missing the required parameter `asset_id` when calling `get_asset_input_info`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'asset_id' in local_var_params:
            path_params['ASSET_ID'] = local_var_params['asset_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['accessToken']  # noqa: E501

        return self.api_client.call_api(
            '/video/v1/assets/{ASSET_ID}/input-info', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetAssetInputInfoResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_asset_playback_id(self, asset_id, playback_id, **kwargs):  # noqa: E501
        """Retrieve a playback ID  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_asset_playback_id(asset_id, playback_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: The asset ID. (required)
        :param str playback_id: The live stream's playback ID. (required)
        :return: GetAssetPlaybackIDResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_asset_playback_id_with_http_info(asset_id, playback_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_asset_playback_id_with_http_info(asset_id, playback_id, **kwargs)  # noqa: E501
            return data

    def get_asset_playback_id_with_http_info(self, asset_id, playback_id, **kwargs):  # noqa: E501
        """Retrieve a playback ID  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_asset_playback_id_with_http_info(asset_id, playback_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: The asset ID. (required)
        :param str playback_id: The live stream's playback ID. (required)
        :return: GetAssetPlaybackIDResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['asset_id', 'playback_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_asset_playback_id" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'asset_id' is set
        if ('asset_id' not in local_var_params or
                local_var_params['asset_id'] is None):
            raise ValueError("Missing the required parameter `asset_id` when calling `get_asset_playback_id`")  # noqa: E501
        # verify the required parameter 'playback_id' is set
        if ('playback_id' not in local_var_params or
                local_var_params['playback_id'] is None):
            raise ValueError("Missing the required parameter `playback_id` when calling `get_asset_playback_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'asset_id' in local_var_params:
            path_params['ASSET_ID'] = local_var_params['asset_id']  # noqa: E501
        if 'playback_id' in local_var_params:
            path_params['PLAYBACK_ID'] = local_var_params['playback_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['accessToken']  # noqa: E501

        return self.api_client.call_api(
            '/video/v1/assets/{ASSET_ID}/playback-ids/{PLAYBACK_ID}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetAssetPlaybackIDResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_assets(self, **kwargs):  # noqa: E501
        """List assets  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_assets(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int limit: Number of items to include in the response
        :param int page: Offset by this many pages, of the size of `limit`
        :return: ListAssetsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_assets_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.list_assets_with_http_info(**kwargs)  # noqa: E501
            return data

    def list_assets_with_http_info(self, **kwargs):  # noqa: E501
        """List assets  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_assets_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int limit: Number of items to include in the response
        :param int page: Offset by this many pages, of the size of `limit`
        :return: ListAssetsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['limit', 'page']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_assets" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'limit' in local_var_params:
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'page' in local_var_params:
            query_params.append(('page', local_var_params['page']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['accessToken']  # noqa: E501

        return self.api_client.call_api(
            '/video/v1/assets', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListAssetsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_asset_master_access(self, asset_id, update_asset_master_access_request, **kwargs):  # noqa: E501
        """Update master access  # noqa: E501

        Allows you add temporary access to the master (highest-quality) version of the asset in MP4 format. A URL will be created that can be used to download the master version for 24 hours. After 24 hours Master Access will revert to \"none\". This master version is not optimized for web and not meant to be streamed, only downloaded for purposes like archiving or editing the video offline.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_asset_master_access(asset_id, update_asset_master_access_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: The asset ID. (required)
        :param UpdateAssetMasterAccessRequest update_asset_master_access_request: (required)
        :return: AssetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_asset_master_access_with_http_info(asset_id, update_asset_master_access_request, **kwargs)  # noqa: E501
        else:
            (data) = self.update_asset_master_access_with_http_info(asset_id, update_asset_master_access_request, **kwargs)  # noqa: E501
            return data

    def update_asset_master_access_with_http_info(self, asset_id, update_asset_master_access_request, **kwargs):  # noqa: E501
        """Update master access  # noqa: E501

        Allows you add temporary access to the master (highest-quality) version of the asset in MP4 format. A URL will be created that can be used to download the master version for 24 hours. After 24 hours Master Access will revert to \"none\". This master version is not optimized for web and not meant to be streamed, only downloaded for purposes like archiving or editing the video offline.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_asset_master_access_with_http_info(asset_id, update_asset_master_access_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: The asset ID. (required)
        :param UpdateAssetMasterAccessRequest update_asset_master_access_request: (required)
        :return: AssetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['asset_id', 'update_asset_master_access_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_asset_master_access" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'asset_id' is set
        if ('asset_id' not in local_var_params or
                local_var_params['asset_id'] is None):
            raise ValueError("Missing the required parameter `asset_id` when calling `update_asset_master_access`")  # noqa: E501
        # verify the required parameter 'update_asset_master_access_request' is set
        if ('update_asset_master_access_request' not in local_var_params or
                local_var_params['update_asset_master_access_request'] is None):
            raise ValueError("Missing the required parameter `update_asset_master_access_request` when calling `update_asset_master_access`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'asset_id' in local_var_params:
            path_params['ASSET_ID'] = local_var_params['asset_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_asset_master_access_request' in local_var_params:
            body_params = local_var_params['update_asset_master_access_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['accessToken']  # noqa: E501

        return self.api_client.call_api(
            '/video/v1/assets/{ASSET_ID}/master-access', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AssetResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_asset_mp4_support(self, asset_id, update_asset_mp4_support_request, **kwargs):  # noqa: E501
        """Update MP4 support  # noqa: E501

        Allows you add or remove mp4 support for assets that were created without it. Currently there are two values supported in this request, `standard` and `none`. `none` means that an asset *does not* have mp4 support, so submitting a request with `mp4_support` set to `none` will delete the mp4 assets from the asset in question.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_asset_mp4_support(asset_id, update_asset_mp4_support_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: The asset ID. (required)
        :param UpdateAssetMP4SupportRequest update_asset_mp4_support_request: (required)
        :return: AssetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_asset_mp4_support_with_http_info(asset_id, update_asset_mp4_support_request, **kwargs)  # noqa: E501
        else:
            (data) = self.update_asset_mp4_support_with_http_info(asset_id, update_asset_mp4_support_request, **kwargs)  # noqa: E501
            return data

    def update_asset_mp4_support_with_http_info(self, asset_id, update_asset_mp4_support_request, **kwargs):  # noqa: E501
        """Update MP4 support  # noqa: E501

        Allows you add or remove mp4 support for assets that were created without it. Currently there are two values supported in this request, `standard` and `none`. `none` means that an asset *does not* have mp4 support, so submitting a request with `mp4_support` set to `none` will delete the mp4 assets from the asset in question.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_asset_mp4_support_with_http_info(asset_id, update_asset_mp4_support_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: The asset ID. (required)
        :param UpdateAssetMP4SupportRequest update_asset_mp4_support_request: (required)
        :return: AssetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['asset_id', 'update_asset_mp4_support_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_asset_mp4_support" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'asset_id' is set
        if ('asset_id' not in local_var_params or
                local_var_params['asset_id'] is None):
            raise ValueError("Missing the required parameter `asset_id` when calling `update_asset_mp4_support`")  # noqa: E501
        # verify the required parameter 'update_asset_mp4_support_request' is set
        if ('update_asset_mp4_support_request' not in local_var_params or
                local_var_params['update_asset_mp4_support_request'] is None):
            raise ValueError("Missing the required parameter `update_asset_mp4_support_request` when calling `update_asset_mp4_support`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'asset_id' in local_var_params:
            path_params['ASSET_ID'] = local_var_params['asset_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_asset_mp4_support_request' in local_var_params:
            body_params = local_var_params['update_asset_mp4_support_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['accessToken']  # noqa: E501

        return self.api_client.call_api(
            '/video/v1/assets/{ASSET_ID}/mp4-support', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AssetResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
Mux Python - Copyright 2019 Mux Inc.

NOTE: This class is auto generated. Do not edit the class manually.
"""


import pprint
import re  # noqa: F401
import six

class Score(object):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'watch_time': 'int',
        'view_count': 'int',
        'name': 'str',
        'value': 'float',
        'metric': 'str',
        'items': 'list[Metric]'
    }

    attribute_map = {
        'watch_time': 'watch_time',
        'view_count': 'view_count',
        'name': 'name',
        'value': 'value',
        'metric': 'metric',
        'items': 'items'
    }

    def __init__(self, watch_time=None, view_count=None, name=None, value=None, metric=None, items=None):  # noqa: E501
        """Score - a model defined in OpenAPI"""  # noqa: E501

        self._watch_time = None
        self._view_count = None
        self._name = None
        self._value = None
        self._metric = None
        self._items = None
        self.discriminator = None

        if watch_time is not None:
            self.watch_time = watch_time
        if view_count is not None:
            self.view_count = view_count
        if name is not None:
            self.name = name
        if value is not None:
            self.value = value
        if metric is not None:
            self.metric = metric
        if items is not None:
            self.items = items

    @property
    def watch_time(self):
        """Gets the watch_time of this Score.  # noqa: E501


        :return: The watch_time of this Score.  # noqa: E501
        :rtype: int
        """
        return self._watch_time

    @watch_time.setter
    def watch_time(self, watch_time):
        """Sets the watch_time of this Score.


        :param watch_time: The watch_time of this Score.  # noqa: E501
        :type: int
        """

        self._watch_time = watch_time

    @property
    def view_count(self):
        """Gets the view_count of this Score.  # noqa: E501


        :return: The view_count of this Score.  # noqa: E501
        :rtype: int
        """
        return self._view_count

    @view_count.setter
    def view_count(self, view_count):
        """Sets the view_count of this Score.


        :param view_count: The view_count of this Score.  # noqa: E501
        :type: int
        """

        self._view_count = view_count

    @property
    def name(self):
        """Gets the name of this Score.  # noqa: E501


        :return: The name of this Score.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Score.


        :param name: The name of this Score.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def value(self):
        """Gets the value of this Score.  # noqa: E501


        :return: The value of this Score.  # noqa: E501
        :rtype: float
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this Score.


        :param value: The value of this Score.  # noqa: E501
        :type: float
        """

        self._value = value

    @property
    def metric(self):
        """Gets the metric of this Score.  # noqa: E501


        :return: The metric of this Score.  # noqa: E501
        :rtype: str
        """
        return self._metric

    @metric.setter
    def metric(self, metric):
        """Sets the metric of this Score.


        :param metric: The metric of this Score.  # noqa: E501
        :type: str
        """

        self._metric = metric

    @property
    def items(self):
        """Gets the items of this Score.  # noqa: E501


        :return: The items of this Score.  # noqa: E501
        :rtype: list[Metric]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this Score.


        :param items: The items of this Score.  # noqa: E501
        :type: list[Metric]
        """

        self._items = items

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Score):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
Mux Python - Copyright 2019 Mux Inc.

NOTE: This class is auto generated. Do not edit the class manually.
"""


import pprint
import re  # noqa: F401
import six

class InputTrack(object):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'duration': 'float',
        'encoding': 'str',
        'width': 'int',
        'height': 'int',
        'frame_rate': 'float',
        'sample_rate': 'int',
        'sample_size': 'int',
        'channels': 'int'
    }

    attribute_map = {
        'type': 'type',
        'duration': 'duration',
        'encoding': 'encoding',
        'width': 'width',
        'height': 'height',
        'frame_rate': 'frame_rate',
        'sample_rate': 'sample_rate',
        'sample_size': 'sample_size',
        'channels': 'channels'
    }

    def __init__(self, type=None, duration=None, encoding=None, width=None, height=None, frame_rate=None, sample_rate=None, sample_size=None, channels=None):  # noqa: E501
        """InputTrack - a model defined in OpenAPI"""  # noqa: E501

        self._type = None
        self._duration = None
        self._encoding = None
        self._width = None
        self._height = None
        self._frame_rate = None
        self._sample_rate = None
        self._sample_size = None
        self._channels = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if duration is not None:
            self.duration = duration
        if encoding is not None:
            self.encoding = encoding
        if width is not None:
            self.width = width
        if height is not None:
            self.height = height
        if frame_rate is not None:
            self.frame_rate = frame_rate
        if sample_rate is not None:
            self.sample_rate = sample_rate
        if sample_size is not None:
            self.sample_size = sample_size
        if channels is not None:
            self.channels = channels

    @property
    def type(self):
        """Gets the type of this InputTrack.  # noqa: E501


        :return: The type of this InputTrack.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this InputTrack.


        :param type: The type of this InputTrack.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def duration(self):
        """Gets the duration of this InputTrack.  # noqa: E501


        :return: The duration of this InputTrack.  # noqa: E501
        :rtype: float
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this InputTrack.


        :param duration: The duration of this InputTrack.  # noqa: E501
        :type: float
        """

        self._duration = duration

    @property
    def encoding(self):
        """Gets the encoding of this InputTrack.  # noqa: E501


        :return: The encoding of this InputTrack.  # noqa: E501
        :rtype: str
        """
        return self._encoding

    @encoding.setter
    def encoding(self, encoding):
        """Sets the encoding of this InputTrack.


        :param encoding: The encoding of this InputTrack.  # noqa: E501
        :type: str
        """

        self._encoding = encoding

    @property
    def width(self):
        """Gets the width of this InputTrack.  # noqa: E501


        :return: The width of this InputTrack.  # noqa: E501
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this InputTrack.


        :param width: The width of this InputTrack.  # noqa: E501
        :type: int
        """

        self._width = width

    @property
    def height(self):
        """Gets the height of this InputTrack.  # noqa: E501


        :return: The height of this InputTrack.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this InputTrack.


        :param height: The height of this InputTrack.  # noqa: E501
        :type: int
        """

        self._height = height

    @property
    def frame_rate(self):
        """Gets the frame_rate of this InputTrack.  # noqa: E501


        :return: The frame_rate of this InputTrack.  # noqa: E501
        :rtype: float
        """
        return self._frame_rate

    @frame_rate.setter
    def frame_rate(self, frame_rate):
        """Sets the frame_rate of this InputTrack.


        :param frame_rate: The frame_rate of this InputTrack.  # noqa: E501
        :type: float
        """

        self._frame_rate = frame_rate

    @property
    def sample_rate(self):
        """Gets the sample_rate of this InputTrack.  # noqa: E501


        :return: The sample_rate of this InputTrack.  # noqa: E501
        :rtype: int
        """
        return self._sample_rate

    @sample_rate.setter
    def sample_rate(self, sample_rate):
        """Sets the sample_rate of this InputTrack.


        :param sample_rate: The sample_rate of this InputTrack.  # noqa: E501
        :type: int
        """

        self._sample_rate = sample_rate

    @property
    def sample_size(self):
        """Gets the sample_size of this InputTrack.  # noqa: E501


        :return: The sample_size of this InputTrack.  # noqa: E501
        :rtype: int
        """
        return self._sample_size

    @sample_size.setter
    def sample_size(self, sample_size):
        """Sets the sample_size of this InputTrack.


        :param sample_size: The sample_size of this InputTrack.  # noqa: E501
        :type: int
        """

        self._sample_size = sample_size

    @property
    def channels(self):
        """Gets the channels of this InputTrack.  # noqa: E501


        :return: The channels of this InputTrack.  # noqa: E501
        :rtype: int
        """
        return self._channels

    @channels.setter
    def channels(self, channels):
        """Sets the channels of this InputTrack.


        :param channels: The channels of this InputTrack.  # noqa: E501
        :type: int
        """

        self._channels = channels

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InputTrack):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
